;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "mantra" "20250920.129"
  "A system for scripting and parsing activity beyond macros."
  '((emacs  "27.1")
    (pubsub "0.1"))
  :url "https://github.com/countvajhula/mantra"
  :commit "ad46c9d7fdcd50d771f129fd458f85bf6e28dd9d"
  :revdesc "ad46c9d7fdcd"
  :authors '(("Sid Kasivajhula" . "sid@countvajhula.com"))
  :maintainers '(("Sid Kasivajhula" . "sid@countvajhula.com")))
